@@ -114,6 +114,7 @@ AnjutaToken *anjuta_token_parent (AnjutaToken *token);
 AnjutaToken *anjuta_token_list (AnjutaToken *token);
 AnjutaToken *anjuta_token_next_after_children (AnjutaToken *token);
 void anjuta_token_foreach_content (AnjutaToken *token, AnjutaTokenForeachFunc func, gpointer user_data);
+void anjuta_token_foreach_token (AnjutaToken *token, AnjutaTokenForeachFunc func, gpointer user_data);
 AnjutaToken *anjuta_token_foreach_post_order (AnjutaToken *token, AnjutaTokenForeachFunc func, gpointer user_data);
 
 AnjutaToken *anjuta_token_first_item (AnjutaToken *list);
@@ -127,6 +128,7 @@ AnjutaToken *anjuta_token_prepend_items (AnjutaToken *list, AnjutaToken *item);
 AnjutaToken *anjuta_token_insert_after (AnjutaToken *sibling, AnjutaToken *token);
 AnjutaToken *anjuta_token_insert_before (AnjutaToken *sibling, AnjutaToken *token);
 AnjutaToken *anjuta_token_delete_parent (AnjutaToken *parent);
+void anjuta_token_remove_item (AnjutaToken *item);
 
 AnjutaToken *anjuta_token_merge (AnjutaToken *first, AnjutaToken *end);
 AnjutaToken *anjuta_token_merge_own_children (AnjutaToken *first);
@@ -134,8 +136,10 @@ AnjutaToken *anjuta_token_merge_children (AnjutaToken *first, AnjutaToken *end);
 AnjutaToken *anjuta_token_merge_previous (AnjutaToken *first, AnjutaToken *end);
 AnjutaToken *anjuta_token_split (AnjutaToken *token, guint size);
 AnjutaToken *anjuta_token_cut (AnjutaToken *token, guint pos, guint size);
+AnjutaToken *anjuta_token_concat(AnjutaToken *token);
 
 gchar *anjuta_token_evaluate (AnjutaToken *token);
+gchar *anjuta_token_evaluate_name (AnjutaToken *token);
 gboolean anjuta_token_is_empty (AnjutaToken *token);
 
 void anjuta_token_dump (AnjutaToken *token);
