@@ -33,6 +33,7 @@
 #include "amp-group.h"
 #include "amp-target.h"
 #include "amp-source.h"
+#include "amp-object.h"
 #include "command-queue.h"
 
 #include <libanjuta/interfaces/ianjuta-project.h>
@@ -620,6 +621,8 @@ amp_project_update_root (AmpProject *project, AmpProject *new_project)
 	style = project->arg_list;
 	project->arg_list = new_project->arg_list;
 	new_project->arg_list = style;
+
+	AMP_NODE_CLASS (parent_class)->update (AMP_NODE (project), AMP_NODE (new_project));
 }
 
 
@@ -680,7 +683,7 @@ amp_project_load_properties (AmpProject *project, AnjutaToken *macro, AnjutaToke
 	{
 		AmpProperty *prop = (AmpProperty *)item->data;
 
-		if (prop->position >= 0)
+		if ((prop->position >= 0) && (prop->token_type == AC_TOKEN_AC_INIT))
 		{
 			AnjutaProjectProperty *new_prop;
 			AnjutaToken *arg;
@@ -729,7 +732,7 @@ amp_project_load_module (AmpProject *project, AnjutaToken *module_token)
 		if (arg != NULL)
 		{
 			scanner = amp_ac_scanner_new (project);
-			list = amp_ac_scanner_parse_token (scanner, arg, AC_SPACE_LIST_STATE, NULL);
+			list = amp_ac_scanner_parse_token (scanner, NULL, arg, AC_SPACE_LIST_STATE, NULL, NULL);
 			anjuta_token_free_children (arg);
 			list = anjuta_token_delete_parent (list);
 			anjuta_token_prepend_items (arg, list);
@@ -788,7 +791,7 @@ amp_project_load_config (AmpProject *project, AnjutaToken *arg_list)
 		scanner = amp_ac_scanner_new (project);
 
 		arg = anjuta_token_first_word (arg_list);
-		list = amp_ac_scanner_parse_token (scanner, arg, AC_SPACE_LIST_STATE, NULL);
+		list = amp_ac_scanner_parse_token (scanner, NULL, arg, AC_SPACE_LIST_STATE, NULL, NULL);
 		anjuta_token_free_children (arg);
 		list = anjuta_token_delete_parent (list);
 		amp_ac_scanner_free (scanner);
@@ -863,7 +866,7 @@ project_load_target (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken
 		}
 
 		/* Create target */
-		target = amp_target_node_new_valid (value, info->base.type, install, flags, NULL);
+		target = amp_target_node_new (value, info->base.type, install, flags);
 		if (target != NULL)
 		{
 			amp_target_node_add_token (target, ANJUTA_TOKEN_ARGUMENT, arg);
@@ -1046,7 +1049,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken
 							obj_file = g_file_get_child (group_file, basename);
 							g_free (basename);
 							g_free (object_name);
-							object = amp_node_new_valid (group, ANJUTA_PROJECT_OBJECT | ANJUTA_PROJECT_PROJECT, obj_file, NULL, NULL);
+							object = amp_object_node_new (obj_file, ANJUTA_PROJECT_PROJECT);
 							g_object_unref (obj_file);
 							anjuta_project_node_append (parent, object);
 							parent = object;
@@ -1057,7 +1060,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken
 			}
 
 			/* Create source */
-			source = amp_node_new_valid (group, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT, src_file, NULL, NULL);
+			source = amp_source_node_new (src_file, ANJUTA_PROJECT_PROJECT);
 			g_object_unref (src_file);
 			if (source != NULL)
 			{
@@ -1070,7 +1073,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken
 
 			g_free (value);
 		}
-		amp_target_changed (target);
+		amp_target_changed (AMP_TARGET_NODE (target));
 	}
 
 	g_object_unref (group_file);
@@ -1110,7 +1113,7 @@ project_load_data (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken *
 	if ((gchar *)find == target_id)
 	{
 		/* Create target */
-		target = amp_target_node_new_valid (target_id, info->base.type, install, flags, NULL);
+		target = amp_target_node_new (target_id, info->base.type, install, flags);
 		if (target != NULL)
 		{
 			anjuta_project_node_append (parent, ANJUTA_PROJECT_NODE (target));
@@ -1140,7 +1143,7 @@ project_load_data (AmpProject *project, AnjutaProjectNode *parent, AnjutaToken *
 
 			/* Create source */
 			src_file = g_file_get_child (parent_file, value);
-			source = amp_node_new_valid (parent, ANJUTA_PROJECT_SOURCE | ANJUTA_PROJECT_PROJECT | data_flags, src_file, NULL, NULL);
+			source = amp_source_node_new (src_file, ANJUTA_PROJECT_PROJECT | data_flags);
 			g_object_unref (src_file);
 			if (source != NULL)
 			{
@@ -1315,7 +1318,7 @@ project_load_subdirs (AmpProject *project, AnjutaToken *list, AnjutaProjectNode
 			else
 			{
 				/* Create new group */
-				group = amp_group_node_new_valid (subdir, dist_only, NULL);
+				group = amp_group_node_new (subdir, dist_only);
 
 				/* Group can be NULL if the name is not valid */
 				if (group != NULL)
@@ -1574,7 +1577,7 @@ amp_project_duplicate_node (AnjutaProjectNode *old_node)
 		// the value will be overwritten with the new node empty value.
 		amp_package_node_add_token (AMP_PACKAGE_NODE (new_node), amp_package_node_get_token (AMP_PACKAGE_NODE (old_node)));
 	}
-	if (anjuta_project_node_get_node_type (old_node) == ANJUTA_PROJECT_ROOT)
+	if (anjuta_project_node_parent (old_node) == NULL)
 	{
 		// FIXME: It would be better to write a duplicate function to avoid this code
 		((AmpProject *)new_node)->lang_manager = (((AmpProject *)old_node)->lang_manager != NULL) ? g_object_ref (((AmpProject *)old_node)->lang_manager) : NULL;
@@ -1645,8 +1648,9 @@ amp_project_load_root (AmpProject *project, GError **error)
 	configure_token_file = amp_project_set_configure (project, configure_file);
 	amp_project_add_file (project, configure_file, configure_token_file);
 	arg = anjuta_token_file_load (configure_token_file, NULL);
+	g_hash_table_remove_all (project->ac_variables);
 	scanner = amp_ac_scanner_new (project);
-	project->configure_token = amp_ac_scanner_parse_token (scanner, arg, 0, &err);
+	project->configure_token = amp_ac_scanner_parse_token (scanner, NULL, arg, 0, configure_file, &err);
 	amp_ac_scanner_free (scanner);
 
 	if (project->configure_token == NULL)
@@ -1664,16 +1668,12 @@ amp_project_load_root (AmpProject *project, GError **error)
 						IANJUTA_PROJECT_ERROR_PROJECT_MALFORMED,
 						_("Unable to parse project file"));
 		}
-		
+
 		return FALSE;
 	}
 
 	/* Load all makefiles recursively */
-	group = amp_group_node_new (root_file, FALSE);
-	g_hash_table_insert (project->groups, g_file_get_uri (root_file), group);
-	anjuta_project_node_append (ANJUTA_PROJECT_NODE (project), ANJUTA_PROJECT_NODE (group));
-
-	if (!amp_node_load (AMP_NODE (group), NULL, project, NULL))
+	if (!AMP_NODE_CLASS (parent_class)->load (AMP_NODE (project), NULL, project, NULL))
 	{
 		g_set_error (error, IANJUTA_PROJECT_ERROR,
 					IANJUTA_PROJECT_ERROR_DOESNT_EXIST,
@@ -1889,6 +1889,9 @@ amp_project_move (AmpProject *project, const gchar *path)
 	root_file = g_file_new_for_path (path);
 	amp_root_node_set_file (AMP_ROOT_NODE (project), root_file);
 
+	/* Root node is a group too */
+	foreach_node_move (ANJUTA_PROJECT_NODE (project), &packet);
+
 	/* Change project root directory in groups */
 	old_hash = project->groups;
 	project->groups = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
@@ -1932,20 +1935,23 @@ amp_project_move (AmpProject *project, const gchar *path)
 
 /* Dump file content of corresponding node */
 gboolean
-amp_project_dump (AmpProject *project, AnjutaProjectNode *node)
+amp_project_dump (AmpProject *project, AnjutaProjectNode *node, AmpFileType type)
 {
 	gboolean ok = FALSE;
 
-	switch (anjuta_project_node_get_node_type (node))
+	if (anjuta_project_node_get_node_type (node) == ANJUTA_PROJECT_GROUP)
 	{
-	case ANJUTA_PROJECT_GROUP:
-		anjuta_token_dump (amp_group_node_get_makefile_token (AMP_GROUP_NODE (node)));
-		break;
-	case ANJUTA_PROJECT_ROOT:
-		anjuta_token_dump (AMP_PROJECT (node)->configure_token);
-		break;
-	default:
-		break;
+		switch (type)
+		{
+		case DUMP_MAKEFILE:
+			anjuta_token_dump (amp_group_node_get_makefile_token (AMP_GROUP_NODE (node)));
+			break;
+		case DUMP_CONFIGURE:
+			anjuta_token_dump (AMP_PROJECT (node)->configure_token);
+			break;
+		default:
+			break;
+		}
 	}
 
 	return ok;
@@ -2034,6 +2040,19 @@ amp_project_add_file (AmpProject *project, GFile *file, AnjutaTokenFile* token)
 	g_object_weak_ref (G_OBJECT (token), remove_config_file, project);
 }
 
+void
+amp_project_add_subst_variable (AmpProject *project, const gchar *name, AnjutaToken *value)
+{
+	g_hash_table_insert (project->ac_variables, (gchar *)name, value);
+}
+
+AnjutaToken *
+amp_project_get_subst_variable_token (AmpProject *project, const gchar *name)
+{
+	return g_hash_table_lookup (project->ac_variables, name);
+}
+
+
 gboolean
 amp_project_is_busy (AmpProject *project)
 {
@@ -2422,6 +2441,11 @@ amp_project_save (AmpNode *root, AmpNode *parent, AmpProject *project, GError **
 		if (!anjuta_token_file_save (tfile, error)) return FALSE;
 	}
 
+	if (!AMP_NODE_CLASS (parent_class)->save (root, parent, project, error))
+	{
+		return FALSE;
+	}
+
 	/* Save all children */
 	for (child = anjuta_project_node_first_child (ANJUTA_PROJECT_NODE (root)); child != NULL; child = anjuta_project_node_next_sibling (child))
 	{
@@ -2460,6 +2484,8 @@ amp_project_dispose (GObject *object)
 	project->groups = NULL;
 	if (project->configs) g_hash_table_destroy (project->configs);
 	project->configs = NULL;
+	if (project->ac_variables) g_hash_table_destroy (project->ac_variables);
+	project->ac_variables = NULL;
 
 	if (project->queue) pm_command_queue_free (project->queue);
 	project->queue = NULL;
@@ -2490,6 +2516,7 @@ amp_project_init (AmpProject *project)
 	project->groups = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 	project->files = NULL;
 	project->configs = g_hash_table_new_full (g_file_hash, (GEqualFunc)g_file_equal, NULL, (GDestroyNotify)amp_config_file_free);
+	project->ac_variables = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify)g_free, NULL);
 
 	/* Default style */
 	project->am_space_list = NULL;
