@@ -39,6 +39,10 @@
 
 #define ANJUTA_STOCK_GOTO_LINE "anjuta-goto-line"
 
+/* width of the entries in chars, that include the space for the icon */
+#define LINE_ENTRY_WIDTH 7
+#define SEARCH_ENTRY_WIDTH 45
+
 typedef struct _SearchBoxPrivate SearchBoxPrivate;
 
 struct _SearchBoxPrivate
@@ -67,6 +71,9 @@ struct _SearchBoxPrivate
 	gboolean highlight_all;	
 	gboolean regex_mode;
 	gboolean highlight_complete;
+
+	/* Incremental search */
+	IAnjutaIterable* last_start;
 	
 };
 
@@ -229,6 +236,11 @@ static gboolean
 on_search_focus_out (GtkWidget* widget, GdkEvent* event, SearchBox* search_box)
 {
 	SearchBoxPrivate* private = GET_PRIVATE(search_box);
+	if (private->last_start)
+	{
+		g_object_unref (private->last_start);
+		private->last_start = NULL;
+	}
 	anjuta_status_pop (private->status);
 
 	return FALSE;
@@ -237,7 +249,7 @@ on_search_focus_out (GtkWidget* widget, GdkEvent* event, SearchBox* search_box)
 
 
 static gboolean
-incremental_regex_search (const gchar* search_entry, const gchar* editor_text, gint * start_pos, gint * end_pos, gboolean search_forward)
+incremental_regex_search (const gchar* search_entry, const gchar* editor_text, gint * start_pos, gint * end_pos)
 {
 	GRegex * regex;
 	GMatchInfo *match_info;
@@ -253,21 +265,11 @@ incremental_regex_search (const gchar* search_entry, const gchar* editor_text, g
 		return FALSE;
 	}
 
-	result = g_regex_match (regex, editor_text, 0, &match_info);
+	g_regex_match (regex, editor_text, 0, &match_info);
+	result = g_match_info_fetch_pos(match_info, 0, start_pos, end_pos);
 
 	if (result)
 	{
-		if (search_forward)
-			g_match_info_fetch_pos(match_info, 0, start_pos, end_pos);
-		else
-		{
-			do
-			{
-				g_match_info_fetch_pos(match_info, 0, start_pos, end_pos);
-			}
-			while (g_match_info_next(match_info, NULL));
-		}
-
 		*start_pos = g_utf8_pointer_to_offset(editor_text, &editor_text[*start_pos]);
 		*end_pos = g_utf8_pointer_to_offset(editor_text, &editor_text[*end_pos]);
 	}
@@ -282,21 +284,20 @@ incremental_regex_search (const gchar* search_entry, const gchar* editor_text, g
 }
 
 gboolean
-search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
-                               gboolean wrap)
+search_box_incremental_search (SearchBox* search_box, gboolean search_forward)
 {
-	IAnjutaIterable* real_start;
 	IAnjutaEditorCell* search_start;
+	IAnjutaIterable* real_start;
 	IAnjutaEditorCell* search_end;
 	IAnjutaEditorCell* result_start;
 	IAnjutaEditorCell* result_end;
 	IAnjutaEditorSelection* selection;
-	SearchBoxPrivate* private = GET_PRIVATE (search_box);
-
+	SearchBoxPrivate* private = GET_PRIVATE(search_box);
+	
 	const gchar* search_text = gtk_entry_get_text (GTK_ENTRY (private->search_entry));
 
 	gboolean found = FALSE;
-
+	
 	if (!private->current_editor || !search_text || !strlen (search_text))
 		return FALSE;
 
@@ -304,281 +305,294 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 
 	if (ianjuta_editor_selection_has_selection (selection, NULL))
 	{
-		search_start =
+		search_start = 
 			IANJUTA_EDITOR_CELL (ianjuta_editor_selection_get_start (selection, NULL));
 	}
 	else
 	{
-		search_start =
-			IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor,
-			                                                  NULL));
+		search_start = 
+			IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor, 
+														  NULL));
 	}
-
 	real_start =
-		ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL);
-
-	/* If forward, set search start and end to current position of
-	 * cursor and editor end, respectively, or if backward to editor
-	 * start and current position of cursor, respectively. Current
-	 * position of cursor is selection start if have selection. */
-	if (search_forward)
-	{
-		search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor,
-	                                                                   NULL));
-		ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
-	}
-	else
-	{
-		search_end = search_start;
-		search_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_position (private->current_editor,
-	                                                                     NULL));
-		ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
-	}
-
-	/* When there's a selection, if forward, set search start and end
-     * to match end and editor end, respectively, or if backward to
-     * editor start and match start, respectively. If forward and
-     * selection starts with a match, look for next match.
+			ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL);
+	
+	search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (private->current_editor, 
+																	   NULL));
+	
+	/* If a search_result is already selected, move the search start
+	 * forward (or backward) by one. Then, if backwards, clone the
+	 * search end to be the search start, and the search start to the
+	 * start of the editor. 
 	 */
 	if (ianjuta_editor_selection_has_selection (selection,
-	                                            NULL))
+												NULL))
 	{
-		IAnjutaIterable* selection_start =
+		IAnjutaIterable* selection_start = 
 			ianjuta_editor_selection_get_start (selection, NULL);
-
-		gchar* selected_text =
-			ianjuta_editor_selection_get (selection, NULL);
-
-		gint start_pos, end_pos;
-		gboolean selected_have_search_text = FALSE;
-
-		if (private->regex_mode)
+		if (ianjuta_iterable_compare (IANJUTA_ITERABLE (search_start),
+									  selection_start, NULL) == 0)
 		{
-			/* Always look for first match */
-			if (incremental_regex_search (search_text, selected_text, &start_pos, &end_pos, TRUE))
+			gchar* selected_text =
+				ianjuta_editor_selection_get (selection, NULL);
+
+			if (private->regex_mode)
 			{
-				selected_have_search_text = TRUE;
+				gint start_pos, end_pos;
+				gboolean result = incremental_regex_search (search_text, selected_text, &start_pos, &end_pos);
+
+				if (result)
+				{
+					if (search_forward)
+					{
+						ianjuta_iterable_next (IANJUTA_ITERABLE (search_start), NULL);
+					}
+					else
+					{
+						search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_selection_get_end (selection, NULL));
+						ianjuta_iterable_previous (IANJUTA_ITERABLE (search_end), NULL);
+						ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
+					}
+				}
 			}
+			else if (private->case_sensitive)
+			{
+				if (g_str_has_prefix (selected_text, search_text))
+				{
+					if (search_forward)
+					{
+						ianjuta_iterable_next (IANJUTA_ITERABLE (search_start), NULL);
+					}					
+					else
+					{
+						search_end = IANJUTA_EDITOR_CELL (ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL));
+						ianjuta_iterable_previous (IANJUTA_ITERABLE (search_end), NULL);
+						ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
+					}				
+				}
+			}
+			else if (strlen (selected_text) >= strlen (search_text))
+			{
+				gchar* selected_up = g_utf8_casefold (selected_text, strlen (search_text));
+				gchar* search_text_up = g_utf8_casefold (search_text, strlen (search_text));
+				if (g_str_equal (selected_up, search_text_up))
+				{
+					if (search_forward)
+					{
+						ianjuta_iterable_next (IANJUTA_ITERABLE (search_start), NULL);
+					}
+					else
+					{
+						search_end = IANJUTA_EDITOR_CELL (ianjuta_iterable_clone (IANJUTA_ITERABLE (search_start), NULL));
+						ianjuta_iterable_previous (IANJUTA_ITERABLE (search_end), NULL);
+						ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
+					}
+				}
+				g_free (selected_up);
+				g_free (search_text_up);
+			}
+			g_free (selected_text);
 		}
-		else if (strlen (selected_text) >= strlen (search_text))
-		{
-			gchar* selected_text_case;
-			gchar* search_text_case;
-
-			if (private->case_sensitive)
-			{
-				selected_text_case = g_strdup (selected_text);
-				search_text_case = g_strdup (search_text);
-			}
-			else
-			{
-				selected_text_case = g_utf8_casefold (selected_text, strlen (selected_text));
-				search_text_case = g_utf8_casefold (search_text, strlen (search_text));
-			}
-
-			gchar* strstr = g_strstr_len (selected_text_case, -1, search_text_case);
-
-			if (strstr)
-			{
-				start_pos = g_utf8_pointer_to_offset(selected_text_case, strstr);
-				end_pos = g_utf8_pointer_to_offset(selected_text_case, strstr + strlen (search_text));
-				selected_have_search_text = TRUE;
-			}
-
-			g_free (selected_text_case);
-			g_free (search_text_case);
-		}
-
-		if (selected_have_search_text)
-		{
-			if (search_forward && start_pos == 0)
-			{
-				end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (selection_start), NULL);
-				ianjuta_iterable_set_position (IANJUTA_ITERABLE(search_start), end_pos, NULL);
-				ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
-			}
-			else if (!search_forward)
-			{
-				start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (selection_start), NULL);
-				ianjuta_iterable_set_position (IANJUTA_ITERABLE(search_end), start_pos, NULL);
-				ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
-			}
-		}
-
-		g_free (selected_text);
-
 		g_object_unref (selection_start);
 	}
 
-	gboolean result_set = FALSE;
-
-	gint start_pos, end_pos;
-	gchar * text_to_search;
-	gboolean result;
-
-	if (!found)
+	if (private->regex_mode)
 	{
-		/* Try searching in current position */
-		if (private->regex_mode)
+		gint start_pos, end_pos;
+		gchar * text_to_search, * text_to_reverse;
+		gboolean result;
+
+		if (search_forward)
 		{
 			text_to_search = ianjuta_editor_get_text (private->current_editor,
-				                                      IANJUTA_ITERABLE (search_start),
-				                                      IANJUTA_ITERABLE (search_end), NULL);
-
-			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos, search_forward);
-
-			start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
-			end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
-
-			if (result && start_pos >= 0)
-			{
-				result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
-					                                                                   NULL));
-				result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
-					                                                                 NULL));
-
-				if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
-					ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
-				{
-					found = TRUE;
-				}
-
-				if (!found)
-				{
-					g_object_unref(result_start);
-					g_object_unref(result_end);
-				}
-			}
-
-			g_free(text_to_search);
-		}
-		else
-		{
-			if (search_forward)
-			{
-				if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (private->current_editor),
-					                               search_text, private->case_sensitive,
-					                               search_start, search_end,
-					                               &result_start,
-					                               &result_end, NULL))
-				{
-					found = TRUE;
-				}
-			}
-			else
-			{
-				if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (private->current_editor),
-					                                search_text, private->case_sensitive,
-					                                search_end, search_start,
-					                                &result_start,
-					                                &result_end, NULL))
-				{
-					found = TRUE;
-				}
-			}
-		}
-	}
-
-	if (found)
-	{
-		anjuta_status_pop (ANJUTA_STATUS (private->status));
-	}
-	else if (wrap)
-	{
-		/* Try to wrap if not found */
-		ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
-		ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
-
-		/* Try to search again */
-		if (private->regex_mode)
-		{
-			text_to_search = ianjuta_editor_get_text (private->current_editor,
-			                                          IANJUTA_ITERABLE(search_start),
-			                                          IANJUTA_ITERABLE(search_end), NULL);
-
-			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos, search_forward);
+													IANJUTA_ITERABLE(search_start),
+													IANJUTA_ITERABLE(search_end), NULL);
+			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos);
 
 			start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
 			end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
 
-			if (result && start_pos >= 0)
-			{
-				result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
-				                                                                       NULL));
-				result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
-				                                                                     NULL));
-
-				if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
-				    ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
-				{
-					result_set = TRUE;
-				}
-
-				if (!result_set)
-				{
-					g_object_unref(result_start);
-					g_object_unref(result_end);
-				}
-			}
 		}
 		else
 		{
+			text_to_reverse = ianjuta_editor_get_text (private->current_editor,
+													IANJUTA_ITERABLE(search_end),
+													IANJUTA_ITERABLE(search_start), NULL);
+
+			text_to_search = g_utf8_strreverse(text_to_reverse, strlen( text_to_reverse ));
+
+			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos);
+
+			start_pos = ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_end), NULL) - start_pos;
+			end_pos = ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_end), NULL) - end_pos;
+
+			g_free(text_to_reverse);
+
+		}
+
+		if (result && start_pos >= 0)
+		{
+
+			result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+			result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+
+			if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
+				ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
+			{
+				found = TRUE;
+				anjuta_status_pop (ANJUTA_STATUS (private->status));
+			}
+		
+		}
+		else
+		{
+			/* Try to wrap search around */
 			if (search_forward)
 			{
-				if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (private->current_editor),
-				                                   search_text, private->case_sensitive,
-				                                   search_start, search_end,
-				                                   &result_start,
-				                                   &result_end, NULL))
-				{
-					result_set = TRUE;
-				}
+				ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
+
+				text_to_search = ianjuta_editor_get_text (private->current_editor,
+													IANJUTA_ITERABLE(search_start),
+													IANJUTA_ITERABLE(search_end), NULL);
+
+				result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos);
+
+				start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
+				end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
 			}
 			else
 			{
-				if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (private->current_editor),
-				                                    search_text, private->case_sensitive,
-				                                    search_end, search_start,
-				                                    &result_start,
-				                                    &result_end, NULL))
+				search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (private->current_editor,
+																	   NULL));
+				search_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+
+				text_to_reverse = ianjuta_editor_get_text (private->current_editor,
+													IANJUTA_ITERABLE(search_end),
+													IANJUTA_ITERABLE(search_start), NULL);
+
+				text_to_search = g_utf8_strreverse(text_to_reverse, strlen( text_to_reverse ));
+				result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos);
+
+				start_pos = ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_end), NULL) - start_pos;
+				end_pos = ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_end), NULL) - end_pos;
+				
+				g_free(text_to_reverse);
+			}
+
+			result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+			result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+
+			if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
+				ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
+			{
+				if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
+				                              real_start, NULL) != 0)
 				{
-					result_set = TRUE;
+					found = TRUE;
+					anjuta_status_push (private->status,
+					                    _("Search for \"%s\" reached the end and wrapped around."), search_text);
+				}
+				else if (ianjuta_editor_selection_has_selection (selection, NULL))
+				{
+					anjuta_status_pop (private->status);
+					anjuta_status_push (private->status,
+					                    _("Search for \"%s\" reached the end and wrapped around but no new match was found."), search_text);
 				}
 			}
+
 		}
 
-		/* Check if successful */
-		if (result_set)
+		g_free(text_to_search);
+		if (!found)
 		{
-			if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
-			                              real_start, NULL) != 0)
+			g_object_unref(result_start);
+			g_object_unref(result_end);
+		}
+		start_pos = 0;
+		end_pos = 0;
+
+	}
+	else if (search_forward)
+	{
+		if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (private->current_editor),
+		                                   search_text, private->case_sensitive,
+		                                   search_start, search_end, 
+		                                   &result_start,
+		                                   &result_end, NULL))
+		{
+			found = TRUE;
+			anjuta_status_pop (ANJUTA_STATUS (private->status));
+		}
+		else
+		{
+			/* Try to continue on top */
+			ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
+
+			if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (private->current_editor),
+			                                   search_text, private->case_sensitive,
+			                                   search_start, search_end, 
+			                                   &result_start,
+			                                   &result_end, NULL))
 			{
-				found = TRUE;
-				anjuta_status_pop (private->status);
-				if (search_forward)
+				if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
+				                              real_start, NULL) != 0)
 				{
-					anjuta_status_push (private->status,
+					found = TRUE;
+					anjuta_status_push (private->status, 
 					                    _("Search for \"%s\" reached the end and was continued at the top."), search_text);
 				}
-				else
+				else if (ianjuta_editor_selection_has_selection (selection, NULL))
 				{
-					anjuta_status_push (private->status,
+					anjuta_status_pop (private->status);
+					anjuta_status_push (private->status, 
+					                    _("Search for \"%s\" reached the end and was continued at the top but no new match was found."), search_text);
+				}				
+			}
+		}
+	}
+	else
+	{
+
+		if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (private->current_editor),
+		                                   search_text, private->case_sensitive,
+		                                   search_end, search_start, 
+		                                   &result_start,
+		                                   &result_end, NULL))
+		{
+			found = TRUE;
+			anjuta_status_pop (ANJUTA_STATUS (private->status));
+		}
+		else
+		{
+			/* Try to continue on buttom */
+			search_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (private->current_editor,
+																	   NULL));
+			search_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (private->current_editor,
+																	   NULL));
+			if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (private->current_editor),
+			                                   search_text, private->case_sensitive,
+			                                   search_end, search_start, 
+			                                   &result_start,
+			                                   &result_end, NULL))
+			{
+				if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
+				                              real_start, NULL) != 0)
+				{
+					found = TRUE;
+					anjuta_status_push (private->status, 
 					                    _("Search for \"%s\" reached top and was continued at the bottom."), search_text);
 				}
-			}
-			else if (ianjuta_editor_selection_has_selection (selection, NULL))
-			{
-				anjuta_status_pop (private->status);
-				if (search_forward)
+				else if (ianjuta_editor_selection_has_selection (selection, NULL))
 				{
-					anjuta_status_push (private->status,
-						                _("Search for \"%s\" reached the end and was continued at the top but no new match was found."), search_text);
-				}
-				else
-				{
-					anjuta_status_push (private->status,
-						                _("Search for \"%s\" reached top and was continued at the bottom but no new match was found."), search_text);
-				}
+					anjuta_status_pop (private->status);
+					anjuta_status_push (private->status, 
+					                    _("Search for \"%s\" reached top and was continued at the bottom but no new match was found."), search_text);
+				}				
 			}
 		}
 	}
@@ -586,17 +600,26 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 	if (found)
 	{
 		ianjuta_editor_selection_set (selection,
-		                              IANJUTA_ITERABLE (result_start),
-		                              IANJUTA_ITERABLE (result_end), TRUE, NULL);
+									  IANJUTA_ITERABLE (result_start),
+									  IANJUTA_ITERABLE (result_end), TRUE, NULL);
 		g_object_unref (result_start);
 		g_object_unref (result_end);
 	}
 
 	search_box_set_entry_color (search_box, found);	
 	g_object_unref (real_start);
-	g_object_unref (search_start);
 	g_object_unref (search_end);
 
+	if (private->last_start)
+	{
+		g_object_unref (private->last_start);
+		private->last_start = NULL;
+	}
+	else
+	{
+		g_object_unref (search_start);
+	}
+
 	return found;
 }
 
@@ -667,7 +690,7 @@ search_box_search_highlight_all (SearchBox * search_box, gboolean search_forward
 	ianjuta_indicable_clear(IANJUTA_INDICABLE(private->current_editor), NULL);
 
 	/* Search through editor and highlight instances of search_entry */
-	while ((entry_found = search_box_incremental_search (search_box, search_forward, TRUE)) == TRUE)
+	while ((entry_found = search_box_incremental_search (search_box, search_forward)) == TRUE)
 	{
 		IAnjutaEditorCell * result_begin, * result_end;
 		selection = IANJUTA_EDITOR_SELECTION (private->current_editor);
@@ -706,31 +729,18 @@ search_box_search_highlight_all (SearchBox * search_box, gboolean search_forward
 }
 
 static void
-on_search_box_entry_changed (GtkWidget * widget, SearchBox * search_box)
+on_search_box_document_changed (GtkWidget * widget, SearchBox * search_box)
 {
 	SearchBoxPrivate* private = GET_PRIVATE(search_box);
 
 	if (!private->regex_mode)
 	{
-		GtkEntryBuffer* buffer = gtk_entry_get_buffer (GTK_ENTRY(widget));
-		if (gtk_entry_buffer_get_length (buffer))
-			search_box_incremental_search (search_box, TRUE, TRUE);
-		else
-		{
-			/* clear selection */
-			IAnjutaIterable* cursor = 
-				ianjuta_editor_get_position (IANJUTA_EDITOR (private->current_editor),
-				                             NULL);
-			ianjuta_editor_selection_set (IANJUTA_EDITOR_SELECTION (private->current_editor),
-			                              cursor,
-			                              cursor,
-			                              FALSE, NULL);
-		}
+		search_box_incremental_search (search_box, TRUE);
 	}
 }
 
 static void
-search_box_forward_search (SearchBox * search_box, GtkWidget* widget)
+on_search_box_forward_search (GtkWidget * widget, SearchBox * search_box)
 {
 	SearchBoxPrivate* private = GET_PRIVATE(search_box);
 
@@ -740,7 +750,7 @@ search_box_forward_search (SearchBox * search_box, GtkWidget* widget)
 	}
 	else
 	{
-		search_box_incremental_search (search_box, TRUE, TRUE);
+		search_box_incremental_search (search_box, TRUE);
 	}
 
 }
@@ -756,13 +766,12 @@ on_search_box_backward_search (GtkWidget * widget, SearchBox * search_box)
 	}
 	else
 	{
-		search_box_incremental_search (search_box, FALSE, TRUE);
+		search_box_incremental_search (search_box, FALSE);
 	}
 }
 
 static gboolean
-search_box_replace (SearchBox * search_box, GtkWidget * widget,
-                    gboolean undo /* treat as undo action */)
+on_search_box_replace (GtkWidget * widget, SearchBox * search_box)
 {
 
 	IAnjutaEditorSelection* selection;
@@ -784,7 +793,7 @@ search_box_replace (SearchBox * search_box, GtkWidget * widget,
 			gchar * replacement_text;
 			gint start_pos, end_pos;
 			GError * err = NULL;
-			gboolean result = incremental_regex_search (search_text, selection_text, &start_pos, &end_pos, TRUE);
+			gboolean result = incremental_regex_search (search_text, selection_text, &start_pos, &end_pos);
 				
 			if (result)
 			{
@@ -798,12 +807,10 @@ search_box_replace (SearchBox * search_box, GtkWidget * widget,
 					g_regex_unref(regex);
 				}
                 else
-				{
-					if (undo)
-						ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (selection), NULL);
+				{                           
+					ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (selection), NULL);
 					ianjuta_editor_selection_replace (selection, replacement_text, strlen(replacement_text), NULL);
-					if (undo)
-						ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (selection), NULL);
+					ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (selection), NULL);
  
 					replace_successful = TRUE;
 				}
@@ -817,11 +824,9 @@ search_box_replace (SearchBox * search_box, GtkWidget * widget,
 		else if ((private->case_sensitive && g_str_equal (selection_text, search_text)) ||
 		         (!private->case_sensitive && strcasecmp (selection_text, search_text) == 0))
 		{
-			if (undo)
-				ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (selection), NULL);
+			ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (selection), NULL);
 			ianjuta_editor_selection_replace (selection, replace_text, strlen(replace_text), NULL);
-			if (undo)
-				ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (selection), NULL);
+			ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (selection), NULL);
 
 			replace_successful = TRUE;
 		}
@@ -845,11 +850,11 @@ on_replace_activated (GtkWidget* widget, SearchBox* search_box)
 
 	/* Either replace search-term or try to move search forward to next occurence */
 
-	successful_replace = search_box_replace (search_box, widget, TRUE);
+	successful_replace = on_search_box_replace (widget, search_box);
 
 	if (!successful_replace)
 	{
-		search_box_forward_search (search_box, widget);
+		on_search_box_forward_search (widget, search_box);
 	}	
 }
 
@@ -897,28 +902,18 @@ on_replace_all_activated (GtkWidget* widget, SearchBox* search_box)
 {
 
 	SearchBoxPrivate* private = GET_PRIVATE(search_box);
-	IAnjutaIterable* cursor;
+
+	gboolean entry_found;
 
 	if (!private->current_editor)
 		return;
 
-	/* Cache current position and search from begin */
-	cursor = ianjuta_editor_get_position (IANJUTA_EDITOR (private->current_editor),
-	                                      NULL);
-	ianjuta_editor_goto_start (IANJUTA_EDITOR (private->current_editor), NULL);
-	
 	/* Replace all instances of search_entry with replace_entry text */
-	ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (private->current_editor), NULL);
-	while (search_box_incremental_search (search_box, TRUE, FALSE))
+	while ((entry_found = search_box_incremental_search (search_box, TRUE)) == TRUE)
 	{
-		search_box_replace (search_box, widget, FALSE);
+		on_search_box_replace (widget, search_box);
 	}
-	ianjuta_document_end_undo_action (IANJUTA_DOCUMENT (private->current_editor), NULL);
 
-	/* Back to cached position */
-	ianjuta_editor_selection_set (IANJUTA_EDITOR_SELECTION (private->current_editor),
-	                              cursor, cursor, TRUE, NULL);
-	g_object_unref (cursor);
 }
 
 static void
@@ -932,14 +927,14 @@ search_box_init (SearchBox *object)
 	
 	/* Searching */
 	private->search_entry = gtk_entry_new();
-	g_signal_connect_swapped (G_OBJECT (private->search_entry), "activate", 
-	                          G_CALLBACK (search_box_forward_search),
-	                          object);
+	g_signal_connect (G_OBJECT (private->search_entry), "activate", 
+					  G_CALLBACK (on_search_box_forward_search),
+					  object);	
 	g_signal_connect (G_OBJECT (private->search_entry), "key-press-event",
 					  G_CALLBACK (on_entry_key_pressed),
 					  object);
 	g_signal_connect (G_OBJECT (private->search_entry), "changed",
-					  G_CALLBACK (on_search_box_entry_changed),
+					  G_CALLBACK (on_search_box_document_changed),
 					  object);
 	g_signal_connect (G_OBJECT (private->search_entry), "focus-out-event",
 					  G_CALLBACK (on_search_focus_out),
@@ -959,24 +954,18 @@ search_box_init (SearchBox *object)
 					  G_CALLBACK (on_search_box_hide), object);
 	
 	/* Previous, Next Navigation */
-	private->next_button = gtk_button_new ();
-	gtk_container_add (GTK_CONTAINER (private->next_button),
-	                   gtk_image_new_from_stock (GTK_STOCK_GO_FORWARD,
-	                                             GTK_ICON_SIZE_BUTTON));
+	private->next_button = gtk_button_new_from_stock (GTK_STOCK_GO_FORWARD);
 	gtk_button_set_relief (GTK_BUTTON (private->next_button), GTK_RELIEF_NONE);
-	g_signal_connect_swapped (G_OBJECT(private->next_button), "clicked", 
-	                          G_CALLBACK (search_box_forward_search), object);
-	private->previous_button = gtk_button_new ();
-	gtk_container_add (GTK_CONTAINER (private->previous_button),
-	                   gtk_image_new_from_stock (GTK_STOCK_GO_BACK,
-	                                             GTK_ICON_SIZE_BUTTON));
+	g_signal_connect (G_OBJECT(private->next_button), "clicked", 
+					G_CALLBACK (on_search_box_forward_search), object);
+	private->previous_button = gtk_button_new_from_stock (GTK_STOCK_GO_BACK);
 	gtk_button_set_relief (GTK_BUTTON (private->previous_button), GTK_RELIEF_NONE);
 	g_signal_connect (G_OBJECT(private->previous_button), "clicked", 
 					G_CALLBACK (on_search_box_backward_search), object);
 	
 	/* Goto line */
 	private->goto_entry = gtk_entry_new ();
-	gtk_entry_set_width_chars (GTK_ENTRY (private->goto_entry), 7);
+	gtk_entry_set_width_chars (GTK_ENTRY (private->goto_entry), LINE_ENTRY_WIDTH);
 	gtk_entry_set_icon_from_stock (GTK_ENTRY (private->goto_entry),
 	                               GTK_ENTRY_ICON_SECONDARY,
 	                               ANJUTA_STOCK_GOTO_LINE);
@@ -1033,8 +1022,8 @@ search_box_init (SearchBox *object)
 	gtk_grid_attach (GTK_GRID (private->grid), private->replace_all_button, 3, 1, 1, 1);		
 
 	/* Expand search entries (a bit) */
-	gtk_entry_set_width_chars (GTK_ENTRY (private->search_entry), 60);
-	gtk_entry_set_width_chars (GTK_ENTRY (private->replace_entry), 60);
+	gtk_entry_set_width_chars (GTK_ENTRY (private->search_entry), SEARCH_ENTRY_WIDTH);
+	gtk_entry_set_width_chars (GTK_ENTRY (private->replace_entry), SEARCH_ENTRY_WIDTH);
 
 	/* Set nice icons */
 	gtk_entry_set_icon_from_stock (GTK_ENTRY (private->search_entry),
@@ -1047,6 +1036,8 @@ search_box_init (SearchBox *object)
 	/* Pack grid into search box */
 	gtk_box_pack_start (GTK_BOX(object), private->grid, TRUE, TRUE, 0);
 	gtk_widget_show_all (GTK_WIDGET (object));
+
+	private->last_start = NULL;
 	
 }
 
