@@ -76,6 +76,8 @@ struct _GdbPluginClass
 	AnjutaPluginClass parent_class;
 };
 
+#define UNIMPLEMENTED  G_STMT_START { g_warning (G_STRLOC": unimplemented"); } G_STMT_END
+
 /* Terminal functions
  *---------------------------------------------------------------------------*/
 
@@ -242,6 +244,34 @@ gdb_plugin_initialize (GdbPlugin *this)
 	debugger_set_pretty_printers (this->debugger, this->pretty_printers);
 }
 
+/* Helper functions
+ *---------------------------------------------------------------------------*/
+
+static gchar *
+quote_expression (const gchar *expression) {
+	GRegex *regex;
+	gchar *aux, *aux2;
+	gchar *quoted;
+	
+	/* This part is for expressions with an actual \" inside */
+	regex = g_regex_new ("\\\\\"", G_REGEX_MULTILINE, 0, NULL);
+	aux = g_regex_replace_literal (regex, expression, -1, 0, "\\\\\\\"", 0, NULL);
+	g_regex_unref (regex);
+
+	/* This part is for expressions with an " inside */
+	regex = g_regex_new ("(?<!\\\\)\"", G_REGEX_MULTILINE, 0, NULL);
+	aux2 = g_regex_replace_literal (regex, aux, -1, 0, "\\\"", 0, NULL);
+	g_regex_unref (regex);
+	g_free (aux);
+
+	/* Converts newlines in spaces */
+	g_strdelimit (aux2, "\n", ' ');
+	quoted = g_strconcat ("\"",aux2, "\"", NULL); 
+	g_free (aux2);
+	
+	return quoted;
+}
+
 /* Callback for saving session
  *---------------------------------------------------------------------------*/
 
@@ -701,61 +731,49 @@ idebugger_handle_signal (IAnjutaDebugger *plugin, const gchar* name, gboolean st
 static gboolean
 idebugger_info_frame (IAnjutaDebugger *plugin, guint frame, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_frame (this->debugger, frame, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
 idebugger_info_args (IAnjutaDebugger *plugin, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_args (this->debugger, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
 idebugger_info_target (IAnjutaDebugger *plugin, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_target (this->debugger, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
 idebugger_info_program (IAnjutaDebugger *plugin, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_program (this->debugger, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
 idebugger_info_udot (IAnjutaDebugger *plugin, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_udot (this->debugger, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
 idebugger_info_variables (IAnjutaDebugger *plugin, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **err)
 {
-	GdbPlugin *this = ANJUTA_PLUGIN_GDB (plugin);
+	UNIMPLEMENTED;
 
-	debugger_info_variables (this->debugger, callback, user_data);
-
-	return TRUE;
+	return FALSE;
 }
 
 static gboolean
@@ -1148,8 +1166,11 @@ static gboolean
 idebugger_variable_destroy (IAnjutaDebuggerVariable *plugin, const gchar *name, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
+	gchar *quoted;
 
-	debugger_delete_variable (gdb->debugger, name);
+	quoted = quote_expression (name);
+	debugger_delete_variable (gdb->debugger, quoted);
+	g_free (quoted);
 
 	return TRUE;
 }
@@ -1168,8 +1189,11 @@ static gboolean
 idebugger_variable_assign (IAnjutaDebuggerVariable *plugin, const gchar *name, const gchar *value, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
+	gchar *quoted;
 
-	debugger_assign_variable (gdb->debugger, name, value);
+	quoted = quote_expression (name);
+	debugger_assign_variable (gdb->debugger, quoted, value);
+	g_free (quoted);
 
 	return TRUE;
 }
@@ -1178,9 +1202,12 @@ static gboolean
 idebugger_variable_list_children (IAnjutaDebuggerVariable *plugin, const gchar *name, guint from, IAnjutaDebuggerGListCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
+	gchar *quoted;
 
-	debugger_list_variable_children (gdb->debugger, name, from, callback, user_data);
-
+	quoted = quote_expression (name);
+	debugger_list_variable_children (gdb->debugger, quoted, from, callback, user_data);
+	g_free (quoted);
+	
 	return TRUE;
 }
 
@@ -1188,8 +1215,11 @@ static gboolean
 idebugger_variable_create (IAnjutaDebuggerVariable *plugin, const gchar *name, IAnjutaDebuggerVariableCallback callback , gpointer user_data, GError **error)
 {
 	GdbPlugin *gdb = ANJUTA_PLUGIN_GDB (plugin);
+	gchar *quoted;
 
-	debugger_create_variable (gdb->debugger, name, callback, user_data);
+	quoted = quote_expression (name);
+	debugger_create_variable (gdb->debugger, quoted, callback, user_data);
+	g_free (quoted);
 
 	return TRUE;
 }
