@@ -116,6 +116,26 @@ EngineParser::parseExpression(const string &in)
 	return parse_expression (in.c_str ());	
 }
 
+void
+EngineParser::unsetSymbolManager ()
+{
+	if (_query_scope)
+		g_object_unref (_query_scope);
+	_query_scope = NULL;
+
+	if (_query_search)
+		g_object_unref (_query_search);
+	_query_search = NULL;
+
+	if (_query_search_in_scope)
+		g_object_unref (_query_search_in_scope);
+	_query_search_in_scope = NULL;
+
+	if (_query_parent_scope)
+		g_object_unref (_query_parent_scope);
+	_query_parent_scope = NULL;
+}
+
 void 
 EngineParser::setSymbolManager (IAnjutaSymbolManager *manager)
 {
@@ -819,15 +839,28 @@ engine_parser_init (IAnjutaSymbolManager * manager)
 	EngineParser::getInstance ()->setSymbolManager (manager);
 }
 
+void
+engine_parser_deinit ()
+{
+	EngineParser::getInstance ()->unsetSymbolManager ();
+}
+
 IAnjutaIterable *
 engine_parser_process_expression (const gchar *stmt, const gchar * above_text,
     const gchar * full_file_path, gulong linenum)
 {
-	IAnjutaIterable *iter = 
-		EngineParser::getInstance ()->processExpression (stmt, 
-		    											above_text,  
-	    												full_file_path, 
-		    											linenum);
-
-	return iter;
+	try
+	{
+		IAnjutaIterable *iter = 
+			EngineParser::getInstance ()->processExpression (stmt, 
+			                                                 above_text,  
+			                                                 full_file_path, 
+			                                                 linenum);
+		return iter;
+	}
+	catch (const std::exception& error)
+	{
+		g_critical ("cxxparser error: %s", error.what());
+		return NULL;
+	}
 }
